==> webkit2gtk_2.51.1.orig.tar.xz: webkitgtk-2.51.1/Source/WebCore/Modules/mediastream/libwebrtc/LibWebRTCRtpTransformableFrame.h <==
/*
 * Copyright (C) 2020 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WEB_RTC) && USE(LIBWEBRTC)

#include "RTCRtpTransformableFrame.h"
#include <wtf/Ref.h>
#include <wtf/TZoneMalloc.h>

namespace webrtc {
class TransformableFrameInterface;
}

namespace WebCore {

class LibWebRTCRtpTransformableFrame final : public RTCRtpTransformableFrame {
    WTF_MAKE_TZONE_ALLOCATED(LibWebRTCRtpTransformableFrame);
public:
    static Ref<LibWebRTCRtpTransformableFrame> create(std::unique_ptr<webrtc::TransformableFrameInterface>&& frame, bool isAudio) { return adoptRef(*new LibWebRTCRtpTransformableFrame(WTFMove(frame), isAudio)); }
    ~LibWebRTCRtpTransformableFrame();

    std::unique_ptr<webrtc::TransformableFrameInterface> takeRTCFrame();

private:
    LibWebRTCRtpTransformableFrame(std::unique_ptr<webrtc::TransformableFrameInterface>&&, bool isAudio);

    // RTCRtpTransformableFrame
    std::span<const uint8_t> data() const final;
    void setData(std::span<const uint8_t>) final;
    bool isKeyFrame() const final;
    uint64_t timestamp() const final;
    RTCEncodedAudioFrameMetadata audioMetadata() const final;
    RTCEncodedVideoFrameMetadata videoMetadata() const final;
    Ref<RTCRtpTransformableFrame> clone() final;
    void setOptions(const RTCEncodedAudioFrameMetadata&) final;
    void setOptions(const RTCEncodedVideoFrameMetadata&) final;

    std::unique_ptr<webrtc::TransformableFrameInterface> m_rtcFrame;
    bool m_isAudio;
};

} // namespace WebCore

#endif // ENABLE(WEB_RTC) && USE(LIBWEBRTC)

==> webkit2gtk_2.51.91.orig.tar.xz: webkitgtk-2.51.91/Source/WebCore/Modules/mediastream/libwebrtc/LibWebRTCRtpTransformableFrame.h <==
/*
 * Copyright (C) 2020 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WEB_RTC) && USE(LIBWEBRTC)

#include "RTCRtpTransformableFrame.h"
#include <wtf/Ref.h>
#include <wtf/TZoneMalloc.h>

namespace webrtc {
class TransformableFrameInterface;
}

namespace WebCore {

class LibWebRTCRtpTransformableFrame final : public RTCRtpTransformableFrame {
    WTF_MAKE_TZONE_ALLOCATED(LibWebRTCRtpTransformableFrame);
public:
    static Ref<LibWebRTCRtpTransformableFrame> create(std::unique_ptr<webrtc::TransformableFrameInterface>&& frame, bool isAudio) { return adoptRef(*new LibWebRTCRtpTransformableFrame(WTF::move(frame), isAudio)); }
    ~LibWebRTCRtpTransformableFrame();

    std::unique_ptr<webrtc::TransformableFrameInterface> takeRTCFrame();

private:
    LibWebRTCRtpTransformableFrame(std::unique_ptr<webrtc::TransformableFrameInterface>&&, bool isAudio);

    bool isLibWebRTCRtpTransformableFrame() const final { return true; }

    // RTCRtpTransformableFrame
    std::span<const uint8_t> data() const final;
    void setData(std::span<const uint8_t>) final;
    bool isKeyFrame() const final;
    uint64_t timestamp() const final;
    RTCEncodedAudioFrameMetadata audioMetadata() const final;
    RTCEncodedVideoFrameMetadata videoMetadata() const final;
    Ref<RTCRtpTransformableFrame> clone() final;
    void setOptions(const RTCEncodedAudioFrameMetadata&) final;
    void setOptions(const RTCEncodedVideoFrameMetadata&) final;

    std::unique_ptr<webrtc::TransformableFrameInterface> m_rtcFrame;
    bool m_isAudio;
};

} // namespace WebCore

SPECIALIZE_TYPE_TRAITS_BEGIN(WebCore::LibWebRTCRtpTransformableFrame)
    static bool isType(const WebCore::RTCRtpTransformableFrame& backend) { return backend.isLibWebRTCRtpTransformableFrame(); }
SPECIALIZE_TYPE_TRAITS_END()

#endif // ENABLE(WEB_RTC) && USE(LIBWEBRTC)
